
package Apache2::ASP::SessionStateManager::MySQL;

use strict;
use warnings 'all';
use base 'Apache2::ASP::SessionStateManager';

1;# return true:

__END__

=pod

=head1 NAME

Apache2::ASP::SessionStateManager::MySQL - MySQL backend for Apache2::ASP Session state

=head1 DESCRIPTION

This package uses a MySQL database to persist Session state for Apache2::ASP web applications.

=head1 BUGS

It's possible that some bugs have found their way into this release.

Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Apache2-ASP> to submit bug reports.

=head1 HOMEPAGE

Please visit the Apache2::ASP homepage at L<http://www.devstack.com/> to see examples
of Apache2::ASP in action.

=head1 AUTHOR

John Drago <jdrago_999@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright 2007 John Drago, All rights reserved.

This software is free software.  It may be used and distributed under the
same terms as Perl itself.

=cut
